@@ -1,34 +1,23 @@
-from __future__ import absolute_import, unicode_literals
-
 import logging
 import os
 import shutil
-
-from six import PY2
-
-from virtualenv.info import IS_CPYTHON, IS_WIN
-from virtualenv.util.six import ensure_text
-
-if PY2 and IS_CPYTHON and IS_WIN:  # CPython2 on Windows supports unicode paths if passed as unicode
-    norm = lambda src: ensure_text(str(src))  # noqa
-else:
-    norm = str
+from stat import S_IWUSR
 
 
 def ensure_dir(path):
     if not path.exists():
-        logging.debug("create folder %s", ensure_text(str(path)))
-        os.makedirs(norm(path))
+        logging.debug("create folder %s", str(path))
+        os.makedirs(str(path))
 
 
 def ensure_safe_to_do(src, dest):
     if src == dest:
-        raise ValueError("source and destination is the same {}".format(src))
+        raise ValueError(f"source and destination is the same {src}")
     if not dest.exists():
         return
     if dest.is_dir() and not dest.is_symlink():
-        shutil.rmtree(norm(dest))
         logging.debug("remove directory %s", dest)
+        safe_delete(dest)
     else:
         logging.debug("remove file %s", dest)
         dest.unlink()
@@ -45,13 +34,13 @@ def copy(src, dest):
     is_dir = src.is_dir()
     method = copytree if is_dir else shutil.copy
     logging.debug("copy %s", _Debug(src, dest))
-    method(norm(src), norm(dest))
+    method(str(src), str(dest))
 
 
 def copytree(src, dest):
     for root, _, files in os.walk(src):
         dest_dir = os.path.join(dest, os.path.relpath(root, src))
-        if not os.path.exists(dest_dir):
+        if not os.path.isdir(dest_dir):
             os.makedirs(dest_dir)
         for name in files:
             src_f = os.path.join(root, name)
@@ -59,21 +48,31 @@ def copytree(src, dest):
             shutil.copy(src_f, dest_f)
 
 
-class _Debug(object):
+def safe_delete(dest):
+    def onerror(func, path, exc_info):
+        if not os.access(path, os.W_OK):
+            os.chmod(path, S_IWUSR)
+            func(path)
+        else:
+            raise
+
+    shutil.rmtree(str(dest), ignore_errors=True, onerror=onerror)
+
+
+class _Debug:
     def __init__(self, src, dest):
         self.src = src
         self.dest = dest
 
     def __str__(self):
-        return "{}{} to {}".format(
-            "directory " if self.src.is_dir() else "", ensure_text(str(self.src)), ensure_text(str(self.dest))
-        )
+        return f"{'directory ' if self.src.is_dir() else ''}{str(self.src)} to {str(self.dest)}"
 
 
-__all__ = (
+__all__ = [
     "ensure_dir",
     "symlink",
     "copy",
     "symlink",
     "copytree",
-)
+    "safe_delete",
+]
