@@ -1,23 +1,18 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import logging
 import os
 import shutil
 import sys
 from contextlib import contextmanager
 from functools import partial
+from pathlib import Path
 
 import pytest
-import six
 
 from virtualenv.app_data import AppDataDiskFolder
 from virtualenv.discovery.builtin import get_interpreter
 from virtualenv.discovery.py_info import PythonInfo
-from virtualenv.info import IS_PYPY, IS_WIN, PY2, fs_supports_symlink
+from virtualenv.info import IS_WIN, fs_supports_symlink
 from virtualenv.report import LOGGER
-from virtualenv.util.path import Path
-from virtualenv.util.six import ensure_str, ensure_text
 
 
 def pytest_addoption(parser):
@@ -119,7 +114,7 @@ def check_cwd_not_changed_by_test():
     yield
     new = os.getcwd()
     if old != new:
-        pytest.fail("tests changed cwd: {!r} => {!r}".format(old, new))
+        pytest.fail(f"tests changed cwd: {old!r} => {new!r}")
 
 
 @pytest.fixture(autouse=True)
@@ -144,14 +139,14 @@ def change_os_environ(key, value):
 @pytest.fixture(autouse=True, scope="session")
 def ignore_global_config(tmp_path_factory):
     filename = str(tmp_path_factory.mktemp("folder") / "virtualenv-test-suite.ini")
-    with change_os_environ(ensure_str("VIRTUALENV_CONFIG_FILE"), filename):
+    with change_os_environ("VIRTUALENV_CONFIG_FILE", filename):
         yield
 
 
 @pytest.fixture(autouse=True, scope="session")
 def pip_cert(tmp_path_factory):
     # workaround for https://github.com/pypa/pip/issues/8984 - if the certificate is explicitly set no error can happen
-    key = ensure_str("PIP_CERT")
+    key = "PIP_CERT"
     if key in os.environ:
         yield
     else:
@@ -169,9 +164,7 @@ def check_os_environ_stable():
     old = os.environ.copy()
     # ensure we don't inherit parent env variables
     to_clean = {
-        k
-        for k in os.environ.keys()
-        if k.startswith(str("VIRTUALENV_")) or str("VIRTUAL_ENV") in k or k.startswith(str("TOX_"))
+        k for k in os.environ.keys() if k.startswith("VIRTUALENV_") or "VIRTUAL_ENV" in k or k.startswith("TOX_")
     }
     cleaned = {k: os.environ[k] for k, v in os.environ.items()}
     override = {
@@ -195,18 +188,18 @@ def check_os_environ_stable():
                 extra = {k: new[k] for k in set(new) - set(old)}
                 miss = {k: old[k] for k in set(old) - set(new) - to_clean}
                 diff = {
-                    "{} = {} vs {}".format(k, old[k], new[k])
+                    f"{k} = {old[k]} vs {new[k]}"
                     for k in set(old) & set(new)
-                    if old[k] != new[k] and not k.startswith(str("PYTEST_"))
+                    if old[k] != new[k] and not k.startswith("PYTEST_")
                 }
                 if extra or miss or diff:
                     msg = "tests changed environ"
                     if extra:
-                        msg += " extra {}".format(extra)
+                        msg += f" extra {extra}"
                     if miss:
-                        msg += " miss {}".format(miss)
+                        msg += f" miss {miss}"
                     if diff:
-                        msg += " diff {}".format(diff)
+                        msg += f" diff {diff}"
                     pytest.fail(msg)
         finally:
             os.environ.update(cleaned)
@@ -268,7 +261,7 @@ def no_coverage():
 if COVERAGE_RUN:
     import coverage
 
-    class EnableCoverage(object):
+    class EnableCoverage:
         _COV_FILE = Path(coverage.__file__)
         _ROOT_COV_FILES_AND_FOLDERS = [i for i in _COV_FILE.parents[1].iterdir() if i.name.startswith("coverage")]
 
@@ -294,7 +287,7 @@ if COVERAGE_RUN:
 
 @pytest.fixture(scope="session")
 def is_inside_ci():
-    yield bool(os.environ.get(str("CI_RUN")))
+    yield bool(os.environ.get("CI_RUN"))
 
 
 @pytest.fixture(scope="session")
@@ -319,8 +312,6 @@ def special_char_name():
 def special_name_dir(tmp_path, special_char_name):
     dest = Path(str(tmp_path)) / special_char_name
     yield dest
-    if six.PY2 and sys.platform == "win32" and not IS_PYPY:  # pytest python2 windows does not support unicode delete
-        shutil.rmtree(ensure_text(str(dest)))
 
 
 @pytest.fixture(scope="session")
@@ -337,7 +328,7 @@ def current_fastest(current_creators):
 def session_app_data(tmp_path_factory):
     temp_folder = tmp_path_factory.mktemp("session-app-data")
     app_data = AppDataDiskFolder(folder=str(temp_folder))
-    with change_env_var(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(app_data.lock.path)):
+    with change_env_var("VIRTUALENV_OVERRIDE_APP_DATA", str(app_data.lock.path)):
         yield app_data
 
 
@@ -362,7 +353,7 @@ def change_env_var(key, value):
 @pytest.fixture()
 def temp_app_data(monkeypatch, tmp_path):
     app_data = tmp_path / "app-data"
-    monkeypatch.setenv(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(app_data))
+    monkeypatch.setenv("VIRTUALENV_OVERRIDE_APP_DATA", str(app_data))
     return app_data
 
 
@@ -371,7 +362,7 @@ def cross_python(is_inside_ci, session_app_data):
     spec = str(2 if sys.version_info[0] == 3 else 3)
     interpreter = get_interpreter(spec, [], session_app_data)
     if interpreter is None:
-        msg = "could not find {}".format(spec)
+        msg = f"could not find {spec}"
         if is_inside_ci:
             raise RuntimeError(msg)
         pytest.skip(msg=msg)
@@ -380,7 +371,7 @@ def cross_python(is_inside_ci, session_app_data):
 
 @pytest.fixture(scope="session")
 def for_py_version():
-    return "{}.{}".format(*sys.version_info[0:2])
+    return f"{sys.version_info.major}.{sys.version_info.minor}"
 
 
 @pytest.fixture()
@@ -388,11 +379,3 @@ def skip_if_test_in_system(session_app_data):
     current = PythonInfo.current(session_app_data)
     if current.system_executable is not None:
         pytest.skip("test not valid if run under system")
-
-
-def pytest_ignore_collect(path):
-    """
-    We can't just skip these tests due to syntax errors that occurs during
-    collecting tests under a Python 2 host.
-    """
-    return PY2 and str(path).endswith("test_cpython3_win.py")
